@@ -1,9 +1,11 @@
 from typing import Literal
 
+from environs import env
+
 from ._abc import Profile
 
 # ensure profiles are registered
-from ._default import ProfileDefault
+from ._default import ProfileDefault  # noqa: F401
 from ._playground import ProfilePlayground  # noqa: F401
 
 # for code-completion
@@ -12,8 +14,10 @@ type ProfileLike = ProfileName | Profile | type[Profile]
 
 
 def factory(profile: ProfileLike | None = None) -> Profile:
+    if profile is None and env.bool("DEBUG", default=False):
+        profile = "playground"
     if profile is None:
-        return ProfileDefault()
+        profile = env.str("PROFILE", default="default")
     if isinstance(profile, str):
         return Profile[profile]()
     if isinstance(profile, Profile):
